<?php
/**
 * Helper functions related to customizer and options.
 *
 * @package WEN_Corporate
 */

if ( ! function_exists( 'wen_corporate_get_global_layout_options' ) ) :

	/**
	 * Returns global layout options.
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function wen_corporate_get_global_layout_options() {

		$choices = array(
			'left-sidebar'            => esc_html__( 'Primary Sidebar - Content', 'wen-corporate' ),
			'right-sidebar'           => esc_html__( 'Content - Primary Sidebar', 'wen-corporate' ),
			'three-columns'           => esc_html__( 'Three Columns ( Secondary - Content - Primary )', 'wen-corporate' ),
			'three-columns-pcs'       => esc_html__( 'Three Columns ( Primary - Content - Secondary )', 'wen-corporate' ),
			'three-columns-cps'       => esc_html__( 'Three Columns ( Content - Primary - Secondary )', 'wen-corporate' ),
			'three-columns-psc'       => esc_html__( 'Three Columns ( Primary - Secondary - Content )', 'wen-corporate' ),
			'three-columns-pcs-equal' => esc_html__( 'Three Columns ( Equal Primary - Content - Secondary )', 'wen-corporate' ),
			'three-columns-scp-equal' => esc_html__( 'Three Columns ( Equal Secondary - Content - Primary )', 'wen-corporate' ),
			'no-sidebar'              => esc_html__( 'No Sidebar', 'wen-corporate' ),
		);
		$output = apply_filters( 'wen_corporate_filter_layout_options', $choices );
		return $output;

	}

endif;

if ( ! function_exists( 'wen_corporate_get_site_layout_options' ) ) :

	/**
	 * Returns site layout options.
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function wen_corporate_get_site_layout_options() {

		$choices = array(
			'fluid' => esc_html__( 'Fluid', 'wen-corporate' ),
			'boxed' => esc_html__( 'Boxed', 'wen-corporate' ),
		);
		$output = apply_filters( 'wen_corporate_filter_site_layout_options', $choices );
		if ( ! empty( $output ) ) {
			ksort( $output );
		}
		return $output;

	}

endif;

if ( ! function_exists( 'wen_corporate_get_pagination_type_options' ) ) :

	/**
	 * Returns pagination type options.
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function wen_corporate_get_pagination_type_options() {

		$choices = array(
			'default'               => esc_html__( 'Default (Older / Newer Post)', 'wen-corporate' ),
			'numeric'               => esc_html__( 'Numeric', 'wen-corporate' ),
			'infinite-scroll'       => esc_html__( 'Infinite Scroll - Scroll', 'wen-corporate' ),
			'infinite-scroll-click' => esc_html__( 'Infinite Scroll - Click', 'wen-corporate' ),
		);
		return $choices;

	}

endif;

if ( ! function_exists( 'wen_corporate_get_breadcrumb_type_options' ) ) :

	/**
	 * Returns breadcrumb type options.
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function wen_corporate_get_breadcrumb_type_options() {

		$choices = array(
			'disabled' => esc_html__( 'Disabled', 'wen-corporate' ),
			'simple'   => esc_html__( 'Simple', 'wen-corporate' ),
			'advanced' => esc_html__( 'Advanced', 'wen-corporate' ),
		);
		return $choices;

	}

endif;


if ( ! function_exists( 'wen_corporate_get_archive_layout_options' ) ) :

	/**
	 * Returns archive layout options.
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function wen_corporate_get_archive_layout_options() {

		$choices = array(
			'full'    => esc_html__( 'Full Post', 'wen-corporate' ),
			'excerpt' => esc_html__( 'Post Excerpt', 'wen-corporate' ),
		);
		$output = apply_filters( 'wen_corporate_filter_archive_layout_options', $choices );
		if ( ! empty( $output ) ) {
			ksort( $output );
		}
		return $output;

	}

endif;

if ( ! function_exists( 'wen_corporate_get_image_sizes_options' ) ) :

	/**
	 * Returns image sizes options.
	 *
	 * @since 1.0.0
	 *
	 * @param bool  $add_disable True for adding No Image option.
	 * @param array $allowed Allowed image size options.
	 * @return array Image size options.
	 */
	function wen_corporate_get_image_sizes_options( $add_disable = true, $allowed = array(), $show_dimension = true ) {

		global $_wp_additional_image_sizes;
		$get_intermediate_image_sizes = get_intermediate_image_sizes();
		$choices = array();
		if ( true === $add_disable ) {
			$choices['disable'] = esc_html__( 'No Image', 'wen-corporate' );
		}
		$choices['thumbnail'] = esc_html__( 'Thumbnail', 'wen-corporate' );
		$choices['medium']    = esc_html__( 'Medium', 'wen-corporate' );
		$choices['large']     = esc_html__( 'Large', 'wen-corporate' );
		$choices['full']      = esc_html__( 'Full (original)', 'wen-corporate' );

		if ( true === $show_dimension ) {
			foreach ( array( 'thumbnail', 'medium', 'large' ) as $key => $_size ) {
				$choices[ $_size ] = $choices[ $_size ] . ' (' . get_option( $_size . '_size_w' ) . 'x' . get_option( $_size . '_size_h' ) . ')';
			}
		}

		if ( ! empty( $_wp_additional_image_sizes ) && is_array( $_wp_additional_image_sizes ) ) {
			foreach ( $_wp_additional_image_sizes as $key => $size ) {
				$choices[ $key ] = $key;
				if ( true === $show_dimension ){
					$choices[ $key ] .= ' ('. $size['width'] . 'x' . $size['height'] . ')';
				}
			}
		}

		if ( ! empty( $allowed ) ) {
			foreach ( $choices as $key => $value ) {
				if ( ! in_array( $key, $allowed ) ) {
					unset( $choices[ $key ] );
				}
			}
		}

		return $choices;

	}

endif;


if ( ! function_exists( 'wen_corporate_get_image_alignment_options' ) ) :

	/**
	 * Returns image options.
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function wen_corporate_get_image_alignment_options() {

		$choices = array(
			'none'   => _x( 'None', 'Alignment', 'wen-corporate' ),
			'left'   => _x( 'Left', 'Alignment', 'wen-corporate' ),
			'center' => _x( 'Center', 'Alignment', 'wen-corporate' ),
			'right'  => _x( 'Right', 'Alignment', 'wen-corporate' ),
		);
		return $choices;

	}

endif;

if ( ! function_exists( 'wen_corporate_get_featured_slider_transition_effects' ) ) :

	/**
	 * Returns the featured slider transition effects.
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function wen_corporate_get_featured_slider_transition_effects() {

		$choices = array(
			'fade'       => _x( 'fade', 'Transition Effect', 'wen-corporate' ),
			'fadeout'    => _x( 'fadeout', 'Transition Effect', 'wen-corporate' ),
			'none'       => _x( 'none', 'Transition Effect', 'wen-corporate' ),
			'scrollHorz' => _x( 'scrollHorz', 'Transition Effect', 'wen-corporate' ),
			'tileSlide'  => _x( 'tileSlide', 'Transition Effect', 'wen-corporate' ),
			'tileBlind'  => _x( 'tileBlind', 'Transition Effect', 'wen-corporate' ),
			'flipHorz'   => _x( 'flipHorz', 'Transition Effect', 'wen-corporate' ),
			'flipVert'   => _x('flipVert','Transition Effect', 'wen-corporate'),
			'shuffle'    => _x('shuffle','Transition Effect', 'wen-corporate'),
		);
		$output = apply_filters( 'wen_corporate_filter_featured_slider_transition_effects', $choices );
		if ( ! empty( $output ) ) {
			ksort( $output );
		}
		return $output;

	}

endif;

if ( ! function_exists( 'wen_corporate_get_featured_slider_design_options' ) ) :

	/**
	 * Returns the featured slider design options.
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function wen_corporate_get_featured_slider_design_options() {

		$choices = array(
			'design-default' => __( 'Default', 'wen-corporate' ),
			'design-1'       => __( 'Design 1', 'wen-corporate' ),
			'design-2'       => __( 'Design 2', 'wen-corporate' ),
		);
		$output = apply_filters( 'wen_corporate_filter_featured_slider_design_options', $choices );
		return $output;

	}

endif;

if ( ! function_exists( 'wen_corporate_get_featured_slider_content_options' ) ) :

	/**
	 * Returns the featured slider content options.
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function wen_corporate_get_featured_slider_content_options() {

		$choices = array(
			'home-page'   => esc_html__( 'Home Page / Front Page', 'wen-corporate' ),
			'entire-site' => esc_html__( 'Entire Site', 'wen-corporate' ),
			'disabled'    => esc_html__( 'Disabled', 'wen-corporate' ),
		);
		$output = apply_filters( 'wen_corporate_filter_featured_slider_content_options', $choices );
		if ( ! empty( $output ) ) {
			ksort( $output );
		}
		return $output;

	}

endif;

if ( ! function_exists( 'wen_corporate_get_featured_slider_type' ) ) :

	/**
	 * Returns the featured slider type.
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function wen_corporate_get_featured_slider_type() {

		$choices = array(
			'featured-page'     => __( 'Featured Pages', 'wen-corporate' ),
			'featured-category' => __( 'Featured Category', 'wen-corporate' ),
			'featured-post'     => __( 'Featured Posts', 'wen-corporate' ),
			'featured-image'    => __( 'Featured Images', 'wen-corporate' ),
			'featured-tag'      => __( 'Featured Tag', 'wen-corporate' ),
			'demo-slider'       => __( 'Demo Slider', 'wen-corporate' ),
		);
		$output = apply_filters( 'wen_corporate_filter_featured_slider_type', $choices );
		if ( ! empty( $output ) ) {
			ksort( $output );
		}
		return $output;

	}

endif;

if( ! function_exists( 'wen_corporate_get_customizer_font_options' ) ) :

	/**
	 * Returns customizer font options.
	 *
	 * @since 1.0.0
	 */
	function wen_corporate_get_customizer_font_options(){

		$web_fonts = wen_corporate_get_web_fonts();
		$os_fonts  = wen_corporate_get_os_fonts();

		$web_fonts = array_merge( $web_fonts, $os_fonts );

		if ( ! empty( $web_fonts ) ) {
			ksort( $web_fonts );
		}

		$choices = array();

		if ( ! empty( $web_fonts ) ) {
			foreach ( $web_fonts as $k => $v ) {
				$choices[$k] = esc_html( $v['label'] );
			}
		}
		return $choices;

	}

endif;

if( ! function_exists( 'wen_corporate_get_web_fonts' ) ) :

	/**
	 * Returns web font options.
	 *
	 * @since 1.0.0
	 */
	function wen_corporate_get_web_fonts(){

		$choices = array(
			'philosopher' => array(
				'name'  => 'Philosopher',
				'label' => "'Philosopher', sans-serif",
				),
			'open-sans' => array(
				'name'  => 'Open Sans',
				'label' => "'Open Sans', sans-serif",
				),
			'pt-sans' => array(
				'name'  => 'PT Sans',
				'label' => "'PT Sans', sans-serif",
				),
			'merriweather-sans' => array(
				'name'  => 'Merriweather Sans',
				'label' => "'Merriweather Sans', sans-serif",
				),
			'roboto' => array(
				'name'  => 'Roboto',
				'label' => "'Roboto', sans-serif",
				),
			'arizonia' => array(
				'name'  => 'Arizonia',
				'label' => "'Arizonia', cursive",
				),
			'raleway' => array(
				'name'  => 'Raleway',
				'label' => "'Raleway', sans-serif",
				),
			'droid-sans' => array(
				'name'  => 'Droid Sans',
				'label' => "'Droid Sans', sans-serif",
				),
			'lato' => array(
				'name'  => 'Lato',
				'label' => "'Lato', sans-serif",
				),
			'dosis' => array(
				'name'  => 'Dosis',
				'label' => "'Dosis', sans-serif",
				),
			'slabo-27px' => array(
				'name'  => 'Slabo 27px',
				'label' => "'Slabo 27px', serif",
				),
			'oswald' => array(
				'name'  => 'Oswald',
				'label' => "'Oswald', sans-serif",
				),
			'pt-sans-narrow' => array(
				'name'  => 'PT Sans Narrow',
				'label' => "'PT Sans Narrow', sans-serif",
				),
			'josefin-slab' => array(
				'name'  => 'Josefin Slab',
				'label' => "'Josefin Slab', serif",
				),
			'alegreya' => array(
				'name'  => 'Alegreya',
				'label' => "'Alegreya', serif",
				),
			'exo' => array(
				'name'  => 'Exo',
				'label' => "'Exo', sans-serif",
				),
			'signika' => array(
				'name'  => 'Signika',
				'label' => "'Signika', sans-serif",
				),
			'lobster' => array(
				'name'  => 'Lobster',
				'label' => "'Lobster', cursive",
				),
			'indie-flower' => array(
				'name'  => 'Indie Flower',
				'label' => "'Indie Flower', cursive",
				),
			'shadows-into-light' => array(
				'name'  => 'Shadows Into Light',
				'label' => "'Shadows Into Light', cursive",
				),
			'kaushan-script' => array(
				'name'  => 'Kaushan Script',
				'label' => "'Kaushan Script', cursive",
				),
			'dancing-script' => array(
				'name'  => 'Dancing Script',
				'label' => "'Dancing Script', cursive",
				),
			'fredericka-the-great' => array(
				'name'  => 'Fredericka the Great',
				'label' => "'Fredericka the Great', cursive",
				),
			'covered-by-your-grace' => array(
				'name'  => 'Covered By Your Grace',
				'label' => "'Covered By Your Grace', cursive",
				),
			);
		$choices = apply_filters( 'wen_corporate_filter_web_fonts', $choices );

		if ( ! empty( $choices ) ) {
			ksort( $choices );
		}

		return $choices;

	}

endif;

if( ! function_exists( 'wen_corporate_get_os_fonts' ) ) :

	/**
	 * Returns OS font options.
	 *
	 * @since 1.0.0
	 */
	function wen_corporate_get_os_fonts(){

		$choices = array(
			'arial' => array(
				'name'  => 'Arial',
				'label' => "'Arial', sans-serif",
				),
			'georgia' => array(
				'name'  => 'Georgia',
				'label' => "'Georgia', serif",
				),
			'cambria' => array(
				'name'  => 'Cambria',
				'label' => "'Cambria', Georgia, serif",
				),
			'tahoma' => array(
				'name'  => 'Tahoma',
				'label' => "'Tahoma', Geneva, sans-serif",
				),
			'sans-serif' => array(
				'name'  => 'Sans Serif',
				'label' => "'Sans Serif', Arial",
				),
			'verdana' => array(
				'name'  => 'Verdana',
				'label' => "'Verdana', Geneva, sans-serif",
				),
			);
		$choices = apply_filters( 'wen_corporate_filter_os_fonts', $choices );

		if ( ! empty( $choices ) ) {
			ksort( $choices );
		}
		return $choices;

	}

endif;

if( ! function_exists( 'wen_corporate_get_font_family_from_key' ) ) :

	/**
	 * Return font family from font slug.
	 *
	 * @since 1.0.0
	 *
	 * @param string $key Font slug.
	 * @return string Font name.
	 */
	function wen_corporate_get_font_family_from_key( $key ){

		$output = '';

		$web_fonts = wen_corporate_get_web_fonts();
		$os_fonts  = wen_corporate_get_os_fonts();

		$fonts = array_merge( $web_fonts, $os_fonts );

		if ( isset( $fonts[ $key ] ) ) {
			$output = $fonts[ $key ]['label'];
		}
		return $output;

	}

endif;

if( ! function_exists( 'wen_corporate_get_font_family_theme_settings_options' ) ) :

	/**
	 * Returns font family theme settings options.
	 *
	 * @since 1.0.0
	 */
	function wen_corporate_get_font_family_theme_settings_options(){

		$choices = array(
			'font_site_title' => array(
				'label'   => __( 'Site Title', 'wen-corporate' ),
				'default' => 'exo',
				),
			'font_site_tagline' => array(
				'label'   => __( 'Site Tagline', 'wen-corporate' ),
				'default' => 'open-sans',
				),
			'font_site_default' => array(
				'label'   => __( 'Default', 'wen-corporate' ),
				'default' => 'pt-sans',
				),

			'font_content_title' => array(
				'label'   => __( 'Content Title', 'wen-corporate' ),
				'default' => 'open-sans',
				),
			'font_content_body' => array(
				'label'   => __( 'Content Body', 'wen-corporate' ),
				'default' => 'open-sans',
				),
			'font_heading_tags' => array(
				'label'   => __( 'Heading Tags', 'wen-corporate' ),
				'default' => 'exo',
				),
			'font_navigation' => array(
				'label'   => __( 'Navigation', 'wen-corporate' ),
				'default' => 'open-sans',
				),
			);
		return $choices;

	}

endif;

if( ! function_exists( 'wen_corporate_get_default_colors' ) ) :

  /**
   * Returns default colors.
   *
   * @since 1.0.0
   *
   * @param string $scheme Color scheme.
   * @return array Color values based on scheme.
   */
	function wen_corporate_get_default_colors( $scheme = 'default' ){

		$output = array();

		switch ( $scheme ) {

			case 'default':
			default:
			$output = array(
				// Basic.
				'color_basic_background'              => '#eaeaea',
				'color_basic_text'                    => '#686868',
				'color_basic_link'                    => '#219fcd',
				'color_basic_link_hover'              => '#686868',
				'color_basic_heading'                 => '#393939',
				'color_basic_button_background'       => '#219fcd',
				'color_basic_button_text'             => '#ffffff',
				'color_basic_button_background_hover' => '#686868',
				'color_basic_button_text_hover'       => '#ffffff',

				// Header.
				'color_header_background'                     => '#ffffff',
				'color_header_title'                          => '#219fcd',
				'color_header_title_hover'                    => '#686868',
				'color_header_tagline'                        => '#666666',

				// Content.
				'color_content_background'      => '#ffffff',
				'color_content_title'           => '#393939',
				'color_content_text'            => '#686868',
				'color_content_link'            => '#219fcd',
				'color_content_link_hover'      => '#686868',
				'color_content_meta_background' => '#f9f9f9',
				'color_content_meta_link'       => '#219fcd',
				'color_content_meta_link_hover' => '#686868',
				'color_content_meta_icon'       => '#686868',

				// Sidebar.
				'color_sidebar_title'            => '#ffffff',
				'color_sidebar_title_background' => '#219fcd',
				'color_sidebar_text'             => '#686868',
				'color_sidebar_link'             => '#219fcd',
				'color_sidebar_link_hover'       => '#686868',
				'color_sidebar_list_icon'        => '#686868',

				// Home Page Widgets.
				'color_home_widgets_area_background' => '#ffffff',
				'color_home_widgets_title'           => '#686868',
				'color_home_widgets_text'            => '#686868',
				'color_home_widgets_link'            => '#219fcd',
				'color_home_widgets_link_hover'      => '#686868',
				'color_home_widgets_title_border'    =>'#686868',

				// Primary Menu.
				'color_primary_menu_main_background'       => '#ffffff',
				'color_primary_menu_main_border'           => '#dddddd',
				'color_primary_menu_link'                  => '#686868',
				'color_primary_menu_link_hover'            => '#ffffff',
				'color_primary_menu_link_background_hover' => '#219fcd',

				// Footer Widgets.
				'color_footer_widgets_background'   => '#464646',
				'color_footer_widgets_title'        => '#ffffff',
				'color_footer_widgets_title_border' => '#219fcd',
				'color_footer_widgets_text'         => '#bbbbbb',
				'color_footer_widgets_link'         => '#bbbbbb',
				'color_footer_widgets_link_hover'   => '#219fcd',
				'color_footer_widgets_list_icon'    => '#219fcd',

				// Footer area.
				'color_footer_area_background' => '#252525',
				'color_footer_area_text'       => '#ffffff',
				'color_footer_area_link'       => '#bbbbbb',
				'color_footer_area_link_hover' => '#219fcd',

				// Go To Top.
				'color_goto_top_icon'             => '#ffffff',
				'color_goto_top_icon_hover'       => '#ffffff',
				'color_goto_top_background'       => '#686868',
				'color_goto_top_background_hover' => '#686868',

				// Pagination.
				'color_pagination_link'                  => '#ffffff',
				'color_pagination_link_hover'            => '#ffffff',
				'color_pagination_link_background'       => '#219fcd',
				'color_pagination_link_background_hover' => '#686868',

				// Breadcrumb.
				'color_breadcrumb_link'       => '#219fcd',
				'color_breadcrumb_link_hover' => '#686868',
				'color_breadcrumb_text'       => '#686868',

			);
			break;

		} // End switch.

	return $output;

	}

endif;


if( ! function_exists( 'wen_corporate_get_color_theme_settings_options' ) ) :

  /**
   * Returns color theme settings options.
   *
   * @since 1.0.0
   */
  function wen_corporate_get_color_theme_settings_options(){

  	$choices = array(

		// Basic.
  		'color_basic_background' => array(
  			'label'   => __( 'Background Color', 'wen-corporate' ),
  			'section' => 'color_section_basic',
  			),
  		'color_basic_text' => array(
  			'label'   => __( 'Text Color', 'wen-corporate' ),
  			'section' => 'color_section_basic',
  			),
  		'color_basic_link' => array(
  			'label'   => __( 'Link Color', 'wen-corporate' ),
  			'section' => 'color_section_basic',
  			),
  		'color_basic_link_hover' => array(
  			'label'   => __( 'Link Hover Color', 'wen-corporate' ),
  			'section' => 'color_section_basic',
  			),
  		'color_basic_heading' => array(
  			'label'   => __( 'Heading Color', 'wen-corporate' ),
  			'section' => 'color_section_basic',
  			),
  		'color_basic_button_text' => array(
  			'label'   => __( 'Button Text Color', 'wen-corporate' ),
  			'section' => 'color_section_basic',
  			),
  		'color_basic_button_background' => array(
  			'label'   => __( 'Button Background Color', 'wen-corporate' ),
  			'section' => 'color_section_basic',
  			),
  		'color_basic_button_text_hover' => array(
  			'label'   => __( 'Button Text Hover Color', 'wen-corporate' ),
  			'section' => 'color_section_basic',
  			),
  		'color_basic_button_background_hover' => array(
  			'label'   => __( 'Button Background Hover Color', 'wen-corporate' ),
  			'section' => 'color_section_basic',
  			),

		// Header.
  		'color_header_background' => array(
  			'label'   => __( 'Background Color', 'wen-corporate' ),
  			'section' => 'color_section_header',
  			),
  		'color_header_title' => array(
  			'label'   => __( 'Site Title Color', 'wen-corporate' ),
  			'section' => 'color_section_header',
  			),
  		'color_header_title_hover' => array(
  			'label'   => __( 'Site Title Hover Color', 'wen-corporate' ),
  			'section' => 'color_section_header',
  			),
  		'color_header_tagline' => array(
  			'label'   => __( 'Site Tagline Color', 'wen-corporate' ),
  			'section' => 'color_section_header',
  			),

		// Primary Menu.
  		'color_primary_menu_main_background' => array(
  			'label'   => __( 'Main Background Color', 'wen-corporate' ),
  			'section' => 'color_section_primary_menu',
  			),
  		'color_primary_menu_main_border' => array(
  			'label'   => __( 'Main Border Color', 'wen-corporate' ),
  			'section' => 'color_section_primary_menu',
  			),
  		'color_primary_menu_link' => array(
  			'label'   => __( 'Link Color', 'wen-corporate' ),
  			'section' => 'color_section_primary_menu',
  			),
  		'color_primary_menu_link_hover' => array(
  			'label'   => __( 'Link Hover Color', 'wen-corporate' ),
  			'section' => 'color_section_primary_menu',
  			),
  		'color_primary_menu_link_background_hover' => array(
  			'label'   => __( 'Link Background Hover Color', 'wen-corporate' ),
  			'section' => 'color_section_primary_menu',
  			),

		// Content.
  		'color_content_background' => array(
  			'label'   => __( 'Background Color', 'wen-corporate' ),
  			'section' => 'color_section_content',
  			),
  		'color_content_title' => array(
  			'label'   => __( 'Title Color', 'wen-corporate' ),
  			'section' => 'color_section_content',
  			),
  		'color_content_text' => array(
  			'label'   => __( 'Text Color', 'wen-corporate' ),
  			'section' => 'color_section_content',
  			),
  		'color_content_link' => array(
  			'label'   => __( 'Link Color', 'wen-corporate' ),
  			'section' => 'color_section_content',
  			),
  		'color_content_link_hover' => array(
  			'label'   => __( 'Link Hover Color', 'wen-corporate' ),
  			'section' => 'color_section_content',
  			),
  		'color_content_meta_background' => array(
  			'label'   => __( 'Meta Background Color', 'wen-corporate' ),
  			'section' => 'color_section_content',
  			),
  		'color_content_meta_link' => array(
  			'label'   => __( 'Meta Link Color', 'wen-corporate' ),
  			'section' => 'color_section_content',
  			),
  		'color_content_meta_link_hover' => array(
  			'label'   => __( 'Meta Link Hover Color', 'wen-corporate' ),
  			'section' => 'color_section_content',
  			),
  		'color_content_meta_icon' => array(
  			'label'   => __( 'Meta Icon Color', 'wen-corporate' ),
  			'section' => 'color_section_content',
  			),

		// Home Page Widgets.
  		'color_home_widgets_area_background' => array(
  			'label'   => __( 'Widget Area Background Color', 'wen-corporate' ),
  			'section' => 'color_section_home_widgets',
  			),
  		'color_home_widgets_title' => array(
  			'label'   => __( 'Widget Title Color', 'wen-corporate' ),
  			'section' => 'color_section_home_widgets',
  			),
  		'color_home_widgets_title_border' => array(
  			'label'   => __( 'Widget Title Border Color', 'wen-corporate' ),
  			'section' => 'color_section_home_widgets',
  			),
  		'color_home_widgets_text' => array(
  			'label'   => __( 'Text Color', 'wen-corporate' ),
  			'section' => 'color_section_home_widgets',
  			),
  		'color_home_widgets_link' => array(
  			'label'   => __( 'Link Color', 'wen-corporate' ),
  			'section' => 'color_section_home_widgets',
  			),
  		'color_home_widgets_link_hover' => array(
  			'label'   => __( 'Link Hover Color', 'wen-corporate' ),
  			'section' => 'color_section_home_widgets',
  			),

		// Sidebar.
  		'color_sidebar_title' => array(
  			'label'   => __( 'Title Color', 'wen-corporate' ),
  			'section' => 'color_section_sidebar',
		),
  		'color_sidebar_title_background' => array(
  			'label'   => __( 'Title Background Color', 'wen-corporate' ),
  			'section' => 'color_section_sidebar',
		),
  		'color_sidebar_text' => array(
  			'label'   => __( 'Text Color', 'wen-corporate' ),
  			'section' => 'color_section_sidebar',
		),
  		'color_sidebar_link' => array(
  			'label'   => __( 'Link Color', 'wen-corporate' ),
  			'section' => 'color_section_sidebar',
		),
  		'color_sidebar_link_hover' => array(
  			'label'   => __( 'Link Hover Color', 'wen-corporate' ),
  			'section' => 'color_section_sidebar',
		),
  		'color_sidebar_list_icon' => array(
  			'label'   => __( 'List Icon Color', 'wen-corporate' ),
  			'section' => 'color_section_sidebar',
		),

		// Footer area.
  		'color_footer_area_background' => array(
  			'label'   => __( 'Background Color', 'wen-corporate' ),
  			'section' => 'color_section_footer_area',
  			),
  		'color_footer_area_text' => array(
  			'label'   => __( 'Text Color', 'wen-corporate' ),
  			'section' => 'color_section_footer_area',
  			),
  		'color_footer_area_link' => array(
  			'label'   => __( 'Link Color', 'wen-corporate' ),
  			'section' => 'color_section_footer_area',
  			),
  		'color_footer_area_link_hover' => array(
  			'label'   => __( 'Link Hover Color', 'wen-corporate' ),
  			'section' => 'color_section_footer_area',
  			),

		// Go To Top.
  		'color_goto_top_icon' => array(
  			'label'   => __( 'Icon Color', 'wen-corporate' ),
  			'section' => 'color_section_goto_top',
  			),
  		'color_goto_top_icon_hover' => array(
  			'label'   => __( 'Icon Hover Color', 'wen-corporate' ),
  			'section' => 'color_section_goto_top',
  			),
  		'color_goto_top_background' => array(
  			'label'   => __( 'Background Color', 'wen-corporate' ),
  			'section' => 'color_section_goto_top',
  			),
  		'color_goto_top_background_hover' => array(
  			'label'   => __( 'Background Hover Color', 'wen-corporate' ),
  			'section' => 'color_section_goto_top',
  			),

		// Pagination.
  		'color_pagination_link' => array(
  			'label'   => __( 'Link Color', 'wen-corporate' ),
  			'section' => 'color_section_pagination',
  			),
  		'color_pagination_link_hover' => array(
  			'label'   => __( 'Link Hover Color', 'wen-corporate' ),
  			'section' => 'color_section_pagination',
  			),
  		'color_pagination_link_background' => array(
  			'label'   => __( 'Link Background Color', 'wen-corporate' ),
  			'section' => 'color_section_pagination',
  			),
  		'color_pagination_link_background_hover' => array(
  			'label'   => __( 'Link Background Hover Color', 'wen-corporate' ),
  			'section' => 'color_section_pagination',
  			),

		// Breadcrumb.


  		'color_breadcrumb_link' => array(
  			'label'   => __( 'Link Color', 'wen-corporate' ),
  			'section' => 'color_section_breadcrumb',
  			),
  		'color_breadcrumb_link_hover' => array(
  			'label'   => __( 'Link Hover Color', 'wen-corporate' ),
  			'section' => 'color_section_breadcrumb',
  			),
  		'color_breadcrumb_text' => array(
  			'label'   => __( 'Text Color', 'wen-corporate' ),
  			'section' => 'color_section_breadcrumb',
  			),

		// Footer Widgets.
  		'color_footer_widgets_background' => array(
  			'label'   => __( 'Background Color', 'wen-corporate' ),
  			'section' => 'color_section_footer_widgets',
  			),
  		'color_footer_widgets_title' => array(
  			'label'   => __( 'Title Color', 'wen-corporate' ),
  			'section' => 'color_section_footer_widgets',
  			),
  		'color_footer_widgets_title_border' => array(
  			'label'   => __( 'Title Border Color', 'wen-corporate' ),
  			'section' => 'color_section_footer_widgets',
  			),
  		'color_footer_widgets_text' => array(
  			'label'   => __( 'Text Color', 'wen-corporate' ),
  			'section' => 'color_section_footer_widgets',
  			),
  		'color_footer_widgets_link' => array(
  			'label'   => __( 'Link Color', 'wen-corporate' ),
  			'section' => 'color_section_footer_widgets',
  			),
  		'color_footer_widgets_link_hover' => array(
  			'label'   => __( 'Link Hover Color', 'wen-corporate' ),
  			'section' => 'color_section_footer_widgets',
  			),
  		'color_footer_widgets_list_icon' => array(
  			'label'   => __( 'List Icon Color', 'wen-corporate' ),
  			'section' => 'color_section_footer_widgets',
  			),

  		);

    return $choices;

  }

endif;

if( ! function_exists( 'wen_corporate_get_color_sections_options' ) ) :

  /**
   * Returns color sections options.
   *
   * @since 1.0.0
   */
	function wen_corporate_get_color_sections_options(){

		$choices = array(
			'color_section_basic' => array(
				'label' => __( 'Basic Color Options', 'wen-corporate' ),
				),
			'color_section_header' => array(
				'label' => __( 'Header Color Options', 'wen-corporate' ),
				),
			'color_section_primary_menu' => array(
				'label' => __( 'Primary Menu Color Options', 'wen-corporate' ),
				),
			'color_section_content' => array(
				'label' => __( 'Content Color Options', 'wen-corporate' ),
				),
			'color_section_home_widgets' => array(
				'label' => __( 'Home Page Widgets Color Options', 'wen-corporate' ),
				),

			'color_section_sidebar' => array(
				'label' => __( 'Sidebar Color Options', 'wen-corporate' ),
				),
			'color_section_breadcrumb' => array(
				'label' => __( 'Breadcrumb Color Options', 'wen-corporate' ),
				),
			'color_section_goto_top' => array(
				'label' => __( 'Go To Top Color Options', 'wen-corporate' ),
				),
			'color_section_pagination' => array(
				'label' => __( 'Pagination Color Options', 'wen-corporate' ),
				),
			'color_section_footer_widgets' => array(
				'label' => __( 'Footer Widgets Color Options', 'wen-corporate' ),
				),
			'color_section_footer_area' => array(
				'label' => __( 'Footer Area Color Options', 'wen-corporate' ),
				),
			);
		return $choices;
	}

endif;

if( ! function_exists( 'wen_corporate_get_header_layout_options' ) ) :

  /**
   * Returns header layout options.
   *
   * @since 1.0.0
   */
	function wen_corporate_get_header_layout_options(){

		$choices = array(
			'layout-1' => get_template_directory_uri() . '/images/header-layout-1.png',
			'layout-2' => get_template_directory_uri() . '/images/header-layout-2.png',
			'layout-3' => get_template_directory_uri() . '/images/header-layout-3.png',
			);
		return $choices;

	}

endif;

if ( ! function_exists( 'wen_corporate_get_numbers_dropdown_options' ) ) :

	/**
	 * Returns numbers dropdown options.
	 *
	 * @since 1.0.0
	 *
	 * @param int $min Min.
	 * @param int $max Max.
	 *
	 * @return array Options array.
	 */
	function wen_corporate_get_numbers_dropdown_options( $min = 1, $max = 4) {

		$output = array();

		if ( $min <= $max ) {
			for ( $i = $min; $i <= $max; $i++ ) {
				$output[ $i ] = $i;
			}
		}

		return $output;

	}

endif;
