<?php
/**
 * Theme widgets.
 *
 * @package WEN_Corporate
 */

require_once get_template_directory() . '/lib/widget-base/class-widget-base.php';

if ( ! function_exists( 'wen_corporate_load_widgets' ) ) :

	/**
	 * Load widgets.
	 *
	 * @since 1.0.0
	 */
	function wen_corporate_load_widgets() {

		// Welcome widget.
		register_widget( 'WEN_Corporate_Welcome_Widget' );

		// Divider widget.
		register_widget( 'WEN_Corporate_Divider_Widget' );

		// CTA widget.
		register_widget( 'WEN_Corporate_CTA_Widget' );

		// Social widget.
		register_widget( 'WEN_Corporate_Social_Widget' );

		// Featured Page widget.
		register_widget( 'WEN_Corporate_Featured_Page_Widget' );

		// Testimmonials widget.
		register_widget( 'WEN_Corporate_Testimonials_Widget' );

		// Advanced Recent Posts widget.
		register_widget( 'WEN_Corporate_Advanced_Recent_Posts_Widget' );

		// Latest News widget.
		register_widget( 'WEN_Corporate_Latest_News_Widget' );

		// Service widget.
		register_widget( 'WEN_Corporate_Service_Widget' );

		// Teams widget.
		register_widget( 'WEN_Corporate_Teams_Widget' );

		// Recent posts widget.
		register_widget( 'WEN_Corporate_Recent_Posts_Block_Widget' );

	}

endif;

add_action( 'widgets_init', 'wen_corporate_load_widgets' );

if ( ! class_exists( 'WEN_Corporate_Welcome_Widget' ) ) :
	/**
	 * Welcome widget Class.
	 *
	 * @since 1.0.0
	 */
	class WEN_Corporate_Welcome_Widget extends WEN_Corporate_Widget_Base {

		/**
		 * Sets up a new widget instance.
		 *
		 * @since 1.0.0
		 */
		function __construct() {
			$opts = array(
				'classname'   => 'wen_corporate_welcome_widget',
				'description' => __( 'Displays welcome box with title and message.', 'wen-corporate' ),
				'customize_selective_refresh' => true,
				);
			$fields = array(
				'title' => array(
					'label' => __( 'Title:', 'wen-corporate' ),
					'type'  => 'text',
					'class' => 'widefat',
					),
				'description' => array(
					'label' => __( 'Description:', 'wen-corporate' ),
					'type'  => 'textarea',
					'class' => 'widefat',
					),
				);
			parent::__construct( 'wen-corporate-welcome', __( 'Corporate: Welcome', 'wen-corporate' ), $opts, array(), $fields );
		}

		/**
		 * Outputs the content for the current widget instance.
		 *
		 * @since 1.0.0
		 *
		 * @param array $args     Display arguments.
		 * @param array $instance Settings for the current widget instance.
		 */
		function widget( $args, $instance ) {

			$params = $this->get_params( $instance );

			echo $args['before_widget'];

			if ( ! empty( $params['title'] ) ) {
				echo $args['before_title'] . $params['title'] . $args['after_title'];
			}
			if ( ! empty( $params['description'] ) ) {
				echo wp_kses_post( wpautop( $params['description'] ) );
			}

			echo $args['after_widget'];

		}
	}
endif;

if ( ! class_exists( 'WEN_Corporate_Divider_Widget' ) ) :
	/**
	 * Divider widget Class.
	 *
	 * @since 1.0.0
	 */
	class WEN_Corporate_Divider_Widget extends WEN_Corporate_Widget_Base {

		/**
		 * Sets up a new widget instance.
		 *
		 * @since 1.0.0
		 */
		function __construct() {
			$opts = array(
				'classname'   => 'wen_corporate_divider_widget',
				'description' => __( 'Displays horizontal line to provide spacing.', 'wen-corporate' ),
				'customize_selective_refresh' => true,
				);
			$fields = array(
				'message' => array(
					'label' => __( 'No options available for this widget.', 'wen-corporate' ),
					'type'  => 'message',
					'class' => 'widefat',
					),
				);
			parent::__construct( 'wen-corporate-divider', __( 'Corporate: Divider', 'wen-corporate' ), $opts, array(), $fields );
		}

		/**
		 * Outputs the content for the current widget instance.
		 *
		 * @since 1.0.0
		 *
		 * @param array $args     Display arguments.
		 * @param array $instance Settings for the current widget instance.
		 */
		function widget( $args, $instance ) {

			echo '<hr class="wen-corporate-divider" />';

		}
	}
endif;

if ( ! class_exists( 'WEN_Corporate_CTA_Widget' ) ) :
	/**
	 * CTA widget Class.
	 *
	 * @since 1.0.0
	 */
	class WEN_Corporate_CTA_Widget extends WEN_Corporate_Widget_Base {

		/**
		 * Sets up a new widget instance.
		 *
		 * @since 1.0.0
		 */
		function __construct() {
			$opts = array(
				'classname'   => 'wen_corporate_cta_widget',
				'description' => __( 'Call To Action Widget. Displays message and button with URL.', 'wen-corporate' ),
				'customize_selective_refresh' => true,
				);
			$fields = array(
				'title' => array(
					'label' => __( 'Title:', 'wen-corporate' ),
					'type'  => 'text',
					'class' => 'widefat',
					),
				'description' => array(
					'label' => __( 'Description:', 'wen-corporate' ),
					'type'  => 'textarea',
					'class' => 'widefat',
					),
				'button_text' => array(
					'label'   => __( 'Button Text:', 'wen-corporate' ),
					'default' => __( 'Learn more...', 'wen-corporate' ),
					'type'    => 'text',
					'class'   => 'widefat',
					),
				'button_url' => array(
					'label' => __( 'Button URL:', 'wen-corporate' ),
					'type'  => 'url',
					'class' => 'widefat',
					),
				);
			parent::__construct( 'wen-corporate-cta', __( 'Corporate: Call To Action', 'wen-corporate' ), $opts, array(), $fields );
		}

		/**
		 * Outputs the content for the current widget instance.
		 *
		 * @since 1.0.0
		 *
		 * @param array $args     Display arguments.
		 * @param array $instance Settings for the current widget instance.
		 */
		function widget( $args, $instance ) {

			$params = $this->get_params( $instance );

			echo $args['before_widget'];

			if ( ! empty( $params['title'] ) ) {
				echo $args['before_title'] . $params['title'] . $args['after_title'];
			}

			?>
			<div class="cta-content">
				<?php if ( ! empty( $params['description'] ) ) : ?>
				    <div class="cta-description">
				        <?php echo wp_kses_post( wpautop( $params['description'] ) ); ?>
				    </div><!-- .cta-description -->
				<?php endif; ?>
				<?php if ( ! empty( $params['button_text'] ) ) : ?>
				    <div class="cta-button">
				        <a href="<?php echo esc_url( $params['button_url'] ); ?>" class="btn-cta"><?php echo esc_html( $params['button_text'] ); ?></a>
				    </div><!-- .cta-button -->
				<?php endif; ?>
			</div><!-- .cta-content -->
			<?php
			echo $args['after_widget'];

		}
	}
endif;

if ( ! class_exists( 'WEN_Corporate_Social_Widget' ) ) :
	/**
	 * Social widget Class.
	 *
	 * @since 1.0.0
	 */
	class WEN_Corporate_Social_Widget extends WEN_Corporate_Widget_Base {

		/**
		 * Sets up a new widget instance.
		 *
		 * @since 1.0.0
		 */
		function __construct() {
			$opts = array(
				'classname'   => 'wen_corporate_social_widget',
				'description' => __( 'Displays social icons.', 'wen-corporate' ),
				'customize_selective_refresh' => true,
				);
			$fields = array(
				'title' => array(
					'label' => __( 'Title:', 'wen-corporate' ),
					'type'  => 'text',
					'class' => 'widefat',
					),
				);

			if ( ! has_nav_menu( 'social' ) ) {
				$fields['message'] = array(
					'label' => __( 'Social menu is not set. Please create menu and assign it to Social Menu.', 'wen-corporate' ),
					'type'  => 'message',
					'class' => 'widefat',
					);
			}

			parent::__construct( 'wen-corporate-social', __( 'Corporate: Social', 'wen-corporate' ), $opts, array(), $fields );
		}

		/**
		 * Outputs the content for the current widget instance.
		 *
		 * @since 1.0.0
		 *
		 * @param array $args     Display arguments.
		 * @param array $instance Settings for the current widget instance.
		 */
		function widget( $args, $instance ) {

			$params = $this->get_params( $instance );

			echo $args['before_widget'];

			if ( ! empty( $params['title'] ) ) {
				echo $args['before_title'] . $params['title'] . $args['after_title'];
			}

			if ( has_nav_menu( 'social' ) ) {
				wp_nav_menu( array(
					'theme_location' => 'social',
					'container'      => false,
					'depth'          => 1,
					'link_before'    => '<span class="screen-reader-text">',
					'link_after'     => '</span>',
					'item_spacing'   => 'discard',
					) );
			}

			echo $args['after_widget'];

		}
	}
endif;

if ( ! class_exists( 'WEN_Corporate_Service_Widget' ) ) :
	/**
	 * Service widget Class.
	 *
	 * @since 1.0.0
	 */
	class WEN_Corporate_Service_Widget extends WEN_Corporate_Widget_Base {

		/**
		 * Sets up a new widget instance.
		 *
		 * @since 1.0.0
		 */
		function __construct() {
			$opts = array(
				'classname'   => 'wen_corporate_service_widget',
				'description' => __( 'Show your services with icon and read more link.', 'wen-corporate' ),
				'customize_selective_refresh' => true,
				);
			$control_opts = array(
				'width' => 350,
				);
			$fields = array(
				'title' => array(
					'label'   => __( 'Title:', 'wen-corporate' ),
					'type'    => 'text',
					'default' => __( 'Services', 'wen-corporate' ),
					'class'   => 'widefat',
					),
				);
			for( $i = 1; $i <= 4; $i++ ) {
				$fields[ 'block_heading_' . $i ] = array(
					'label' => __( 'Block', 'wen-corporate' ) . ' #' . $i,
					'type'  => 'heading',
					'class' => 'widefat',
					);
				$fields[ 'block_title_' . $i ] = array(
					'label' => __( 'Title:', 'wen-corporate' ),
					'type'  => 'text',
					);
				$fields[ 'block_icon_' . $i ] = array(
					'label'       => __( 'Icon:', 'wen-corporate' ),
					'description' => __( 'Eg: fa-cogs', 'wen-corporate' ),
					'type'        => 'text',
					'default'     => 'fa-cogs',
					);
				$fields[ 'block_description_' . $i ] = array(
					'label' => __( 'Intro:', 'wen-corporate' ),
					'type'  => 'textarea',
					'class' => 'widefat',
					'rows'  => 3,
					);
				$fields[ 'block_read_more_' . $i ] = array(
					'label'   => __( 'Read More Text:', 'wen-corporate' ),
					'type'    => 'text',
					'default' => __( 'Read More', 'wen-corporate' ),
					);
				$fields[ 'block_url_' . $i ] = array(
					'label' => __( 'URL:', 'wen-corporate' ),
					'type'  => 'url',
					);
			}
			parent::__construct( 'wen-corporate-service', __( 'Corporate: Service', 'wen-corporate' ), $opts, $control_opts, $fields );
		}

		/**
		 * Outputs the content for the current widget instance.
		 *
		 * @since 1.0.0
		 *
		 * @param array $args     Display arguments.
		 * @param array $instance Settings for the current widget instance.
		 */
		function widget( $args, $instance ) {

			$params = $this->get_params( $instance );

			echo $args['before_widget'];

			if ( ! empty( $params['title'] ) ) {
				echo $args['before_title'] . $params['title'] . $args['after_title'];
			}
			$service_arr = array();
			for ( $i = 0; $i < 4 ; $i++ ) {
				$block = ( $i + 1 );
				$service_arr[ $i ] = array(
					'title'       => $params[ 'block_title_' . $block ],
					'icon'        => $params[ 'block_icon_' . $block ],
					'description' => $params[ 'block_description_' . $block ],
					'read_more'   => $params[ 'block_read_more_' . $block ],
					'url'         => $params[ 'block_url_' . $block ],
					);
			}
			$refined_arr = array();
			if ( ! empty( $service_arr ) ) {
				foreach ( $service_arr as $item ) {
					if ( ! empty( $item['title'] ) ) {
						$refined_arr[] = $item;
					}
				}
			}
			if ( ! empty( $refined_arr ) ) {
				$this->render_widget_content( $refined_arr );
			}
			echo $args['after_widget'];

		}

		/**
		 * Render services content.
		 *
		 * @since 1.0.0
		 *
		 * @param array $service_arr Services array.
		 */
		function render_widget_content( $service_arr ) {

			$column = count( $service_arr );
			?>
			<div class="service-block-list <?php echo 'services-col-' . absint( $column ) ; ?>">

				<?php foreach ( $service_arr as $key => $service ) :  ?>
					<?php
					$link_open  = '';
					$link_close = '';
					if ( ! empty( $service['url'] ) && ! empty( $service['read_more'] ) ) {
						$link_open  = '<a href="' . esc_url( $service['url'] ) . '">';
						$link_close = '</a>';
					}
					?>

					<div class="service-block-item">
						<div class="service-block-inner">

							<i class="<?php echo 'fa ' . esc_attr( $service['icon'] ); ?>"></i>
							<h3 class="service-item-title">
								<?php printf( '%s%s%s', $link_open, esc_html( $service['title'] ), $link_close ); ?>
							</h3>
							<div class="service-block-item-excerpt">
								<?php
								$description = wp_kses_post( $service['description'] );
								echo wp_kses_post( wpautop( $description ) );
								?>
							</div><!-- .service-block-item-excerpt -->

							<?php if ( ! empty( $link_open ) ) :  ?>
								<a href="<?php echo esc_url( $service['url'] ); ?>" class="read-more"><?php echo esc_html( $service['read_more'] ); ?></a>
							<?php endif ?>

						</div><!-- .service-block-inner -->
					</div><!-- .service-block-item -->

				<?php endforeach ?>

			</div><!-- .service-block-list -->
			<?php

		}

	}
endif;

if ( ! class_exists( 'WEN_Corporate_Recent_Posts_Block_Widget' ) ) :
	/**
	 * Recent Posts widget Class.
	 *
	 * @since 1.0.0
	 */
	class WEN_Corporate_Recent_Posts_Block_Widget extends WEN_Corporate_Widget_Base {

		/**
		 * Sets up a new widget instance.
		 *
		 * @since 1.0.0
		 */
		function __construct() {
			$opts = array(
				'classname'   => 'wen_corporate_recent_posts_block_widget',
				'description' => __( 'Recent Posts Block Widget. Displays posts in carousel slider. Most suitable for Front Page Widget Area.', 'wen-corporate' ),
				);
			$fields = array(
				'title' => array(
					'label' => __( 'Title:', 'wen-corporate' ),
					'type'  => 'text',
					'class' => 'widefat',
					),
				'recent_category' => array(
					'label'           => __( 'Category:', 'wen-corporate' ),
					'type'            => 'dropdown-taxonomies',
					'show_option_all' => __( 'All Categories', 'wen-corporate' ),
					),
				'number_of_posts' => array(
					'label'   => __( 'Number of Posts in a Screen:', 'wen-corporate' ),
					'type'    => 'select',
					'default' => 3,
					'options' => wen_corporate_get_numbers_dropdown_options( 3, 4 ),
					),
				'post_number' => array(
					'label'   => __( 'Number of Posts:', 'wen-corporate' ),
					'type'    => 'number',
					'default' => 6,
					'css'     => 'max-width:60px;',
					'min'     => 3,
					'max'     => 20,
					),
				'show_post_excerpt' => array(
					'label'   => __( 'Show Post Excerpt', 'wen-corporate' ),
					'type'    => 'checkbox',
					'default' => true,
					),
				'post_excerpt_length' => array(
					'label'       => __( 'Excerpt Length:', 'wen-corporate' ),
					'description' => __( 'in words', 'wen-corporate' ),
					'adjacent'    => true,
					'type'        => 'number',
					'default'     => 20,
					'css'         => 'max-width:60px;',
					),
				'show_more_button' => array(
					'label' => __( 'Show More Button', 'wen-corporate' ),
					'type'  => 'checkbox',
					'default' => false,
					),
				'more_button_text' => array(
					'label'   => __( 'More Button Text:', 'wen-corporate' ),
					'default' => __( 'Read more' , 'wen-corporate' ),
					'type'    => 'text',
					'css'     => 'max-width:110px;',
					),
				);
			parent::__construct( 'wen-corporate-recent-posts', __( 'Corporate: Recent Posts Block', 'wen-corporate' ), $opts, array(), $fields );
		}

		/**
		 * Outputs the content for the current widget instance.
		 *
		 * @since 1.0.0
		 *
		 * @param array $args     Display arguments.
		 * @param array $instance Settings for the current widget instance.
		 */
		function widget( $args, $instance ) {

			$params = $this->get_params( $instance );

			echo $args['before_widget'];
			if ( ! empty( $params['title'] ) ) {
				echo $args['before_title'] . $params['title'] . $args['after_title'];
			}
			$this->render_carousel( $params );
			echo $args['after_widget'];

		}
		/**
		 * Render carousel.
		 *
		 * @since 1.0.0
		 *
		 * @param array $params Parameters
		 */
		function render_carousel( $params ) {

			$qargs = array(
				'posts_per_page' => $params['post_number'],
				);
			if ( absint( $params['recent_category'] ) > 0  ) {
				$qargs['category'] = $params['recent_category'];
			}

			$all_posts = get_posts( $qargs );

			$slider_id = 'recent-posts-carousel-' . uniqid();

			global $post;
			?>

			<?php if ( ! empty( $all_posts ) ) : ?>
				<?php
					$carousel_args = array(
						'slidesToShow' => absint( $params['number_of_posts'] ),
						'prevArrow'    => '<span data-role="none" class="slick-prev" tabindex="0"></span>',
						'nextArrow'    => '<span data-role="none" class="slick-next" tabindex="0"></span>',
						'responsive'    => array(
							array(
								'breakpoint' => 1023,
								'settings' => array(
									'slidesToShow' => 3,
									),
								),
							array(
								'breakpoint' => 767,
								'settings' => array(
									'slidesToShow' => 2,
									),
								),
							array(
								'breakpoint' => 479,
								'settings' => array(
									'slidesToShow' => 1,
									),
								),
							),
						);
					$carousel_args_encoded = wp_json_encode( $carousel_args );
				 ?>

				<div id="<?php echo esc_attr( $slider_id ); ?>" class="wen-corporate-carousel" data-slick='<?php echo $carousel_args_encoded; ?>'>
				<?php foreach ( $all_posts as $post ) : ?>
				<?php setup_postdata( $post ); ?>

				<div class="recent-posts-block-item">

					<h3 class="recent-posts-title"><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h3>
					<?php if ( has_post_thumbnail() ): ?>
						<a href="<?php the_permalink(); ?>">
							<?php the_post_thumbnail( 'post-thumb' ); ?>
						</a>
					<?php endif; ?>

					<?php if ( true === $params['show_post_excerpt'] ) :  ?>
						<div class="recent-posts-block-item-excerpt">
							<?php
							$summary = wen_corporate_the_excerpt( esc_attr( $params['post_excerpt_length'] ), $post );
							echo wp_kses_post( wpautop( $summary ) );
							?>
						</div><!-- .recent-posts-block-item-excerpt -->
					<?php endif; ?>


					<?php if ( true === $params['show_more_button'] ) :  ?>
						<a href="<?php the_permalink(); ?>" class="read-more" ><?php echo esc_attr( $params['more_button_text'] ); ?></a>
					<?php endif; ?>

				</div><!-- .recent-posts-block-item -->

				<?php endforeach; ?>
				<?php wp_reset_postdata(); ?>

				</div><!-- .wen-corporate-carousel -->

			<?php endif; ?>
			<?php
		}
	}
endif;

if ( ! class_exists( 'WEN_Corporate_Featured_Page_Widget' ) ) :
	/**
	 * Featured page widget class.
	 *
	 * @since 1.0.0
	 */
	class WEN_Corporate_Featured_Page_Widget extends WEN_Corporate_Widget_Base {

		/**
		 * Sets up a new widget instance.
		 *
		 * @since 1.0.0
		 */
		function __construct() {
			$opts = array(
				'classname'   => 'wen_corporate_widget_featured_page',
				'description' => __( 'Displays single featured Page or Post.', 'wen-corporate' ),
				'customize_selective_refresh' => true,
				);
			$fields = array(
				'title' => array(
					'label' => __( 'Title:', 'wen-corporate' ),
					'type'  => 'text',
					'class' => 'widefat',
					),
				'use_page_title' => array(
					'label'   => __( 'Use Page/Post Title as Widget Title', 'wen-corporate' ),
					'type'    => 'checkbox',
					'default' => true,
					),
				'featured_page' => array(
					'label'            => __( 'Select Page:', 'wen-corporate' ),
					'type'             => 'dropdown-pages',
					'show_option_none' => __( '&mdash; Select &mdash;', 'wen-corporate' ),
					),
				'id_message' => array(
					'label'            => '<strong>' . _x( 'OR', 'Featured Page Widget', 'wen-corporate' ) . '</strong>',
					'type'             => 'message',
					),
				'featured_post' => array(
					'label'       => __( 'Post ID:', 'wen-corporate' ),
					'placeholder' => __( 'Eg: 1234', 'wen-corporate' ),
					'type'        => 'text',
					),
				'content_type' => array(
					'label'   => __( 'Show Content:', 'wen-corporate' ),
					'type'    => 'select',
					'default' => 'full',
					'options' => array(
						'short' => __( 'Short', 'wen-corporate' ),
						'full'  => __( 'Full', 'wen-corporate' ),
						),
					),
				'excerpt_length' => array(
					'label'       => __( 'Excerpt Length:', 'wen-corporate' ),
					'description' => __( 'Applies when Short is selected in Content Type.', 'wen-corporate' ),
					'type'        => 'number',
					'css'         => 'max-width:60px;',
					'default'     => 40,
					'min'         => 1,
					'max'         => 400,
					),
				'featured_image' => array(
					'label'   => __( 'Featured Image:', 'wen-corporate' ),
					'type'    => 'select',
					'options' => wen_corporate_get_image_sizes_options(),
					),
				'featured_image_alignment' => array(
					'label'   => __( 'Image Alignment:', 'wen-corporate' ),
					'type'    => 'select',
					'default' => 'center',
					'options' => wen_corporate_get_image_alignment_options(),
					),
				);
			parent::__construct( 'wen-corporate-featured-page', __( 'Corporate: Featured Page', 'wen-corporate' ), $opts, array(), $fields );
		}

		/**
		 * Outputs the content for the current widget instance.
		 *
		 * @since 1.0.0
		 *
		 * @param array $args     Display arguments.
		 * @param array $instance Settings for the current widget instance.
		 */
		function widget( $args, $instance ) {

			$params = $this->get_params( $instance );

			echo $args['before_widget'];

			// ID validation.
			$our_id = '';

			if ( absint( $params['featured_post'] ) > 0 ) {
				$our_id = absint( $params['featured_post'] );
			}

			if ( absint( $params['featured_page'] ) > 0 ) {
				$our_id = absint( $params['featured_page'] );
			}

			if ( absint( $our_id ) > 0 ) {
				$qargs = array(
					'p'                   => absint( $our_id ),
					'post_type'           => 'any',
					'no_found_rows'       => true,
					'ignore_sticky_posts' => true,
				);

				$the_query = new WP_Query( $qargs );

				if ( $the_query->have_posts() ) {
					while ( $the_query->have_posts() ) {
						$the_query->the_post();

						if ( true === $params['use_page_title'] ) {
							the_title( $args['before_title'], $args['after_title'] );
						} else {
							if ( ! empty( $params['title'] ) ) {
								echo $args['before_title'] . $params['title'] . $args['after_title'];
							}
						}
						?>
						<div class="featured-page-widget entry-content">
							<?php if ( 'disable' !== $params['featured_image'] && has_post_thumbnail() ) : ?>
								<?php the_post_thumbnail( esc_attr( $params['featured_image'] ), array( 'class' => 'align' . esc_attr( $params['featured_image_alignment'] ) ) ); ?>
							<?php endif; ?>

							<?php if ( 'short' === $params['content_type'] ) : ?>
								<?php
								$short = wen_corporate_the_excerpt( $params['excerpt_length'] );
								echo wp_kses_post( wpautop( $short ) );
								?>
							<?php else : ?>
								<?php the_content(); ?>
							<?php endif; ?>
						</div><!-- .featured-page-widget -->
						<?php
					} // End while.

					// Reset.
					wp_reset_postdata();
				} // End if.

			}

			echo $args['after_widget'];
		}
	}
endif;

if ( ! class_exists( 'WEN_Corporate_Advanced_Recent_Posts_Widget' ) ) :
	/**
	 * Advanced Recent Posts widget Class.
	 *
	 * @since 1.0.0
	 */
	class WEN_Corporate_Advanced_Recent_Posts_Widget extends WEN_Corporate_Widget_Base {

		/**
		 * Sets up a new widget instance.
		 *
		 * @since 1.0.0
		 */
		function __construct() {
			$opts = array(
				'classname'   => 'wen_corporate_widget_advanced_recent_posts',
				'description' => __( 'Displays recent posts with thumbnail.', 'wen-corporate' ),
				'customize_selective_refresh' => true,
				);
			$fields = array(
				'title' => array(
					'label' => __( 'Title:', 'wen-corporate' ),
					'type'  => 'text',
					'class' => 'widefat',
					),
				'post_category' => array(
					'label'           => __( 'Select Category:', 'wen-corporate' ),
					'type'            => 'dropdown-taxonomies',
					'show_option_all' => __( 'All Categories', 'wen-corporate' ),
					),
				'post_number' => array(
					'label'   => __( 'Number of Posts:', 'wen-corporate' ),
					'type'    => 'number',
					'default' => 4,
					'css'     => 'max-width:60px;',
					'min'     => 1,
					'max'     => 100,
					),
				'featured_image' => array(
					'label'   => __( 'Featured Image:', 'wen-corporate' ),
					'type'    => 'select',
					'default' => 'thumbnail',
					'options' => wen_corporate_get_image_sizes_options( true, array( 'disable', 'thumbnail' ), false ),
					),
				'image_width' => array(
					'label'       => __( 'Image Width:', 'wen-corporate' ),
					'type'        => 'number',
					'description' => __( 'px', 'wen-corporate' ),
					'css'         => 'max-width:60px;',
					'adjacent'    => true,
					'default'     => 90,
					'min'         => 1,
					'max'         => 150,
					),
				'excerpt_length' => array(
					'label'       => __( 'Excerpt Length:', 'wen-corporate' ),
					'description' => __( 'in words', 'wen-corporate' ),
					'type'        => 'number',
					'css'         => 'max-width:60px;',
					'default'     => 15,
					'min'         => 1,
					'max'         => 400,
					'adjacent'    => true,
					),
				'more_text' => array(
					'label'   => __( 'More Text:', 'wen-corporate' ),
					'type'    => 'text',
					'default' => __( 'Read more', 'wen-corporate' ),
					),
				'disable_date' => array(
					'label'   => __( 'Disable Date', 'wen-corporate' ),
					'type'    => 'checkbox',
					'default' => false,
					),
				'disable_excerpt' => array(
					'label'   => __( 'Disable Excerpt', 'wen-corporate' ),
					'type'    => 'checkbox',
					'default' => true,
					),
				'disable_more_text' => array(
					'label'   => __( 'Disable More Text', 'wen-corporate' ),
					'type'    => 'checkbox',
					'default' => false,
					),
				);
			parent::__construct( 'wen-corporate-advanced-recent-posts', __( 'Corporate: Advanced Recent Posts', 'wen-corporate' ), $opts, array(), $fields );
		}

		/**
		 * Outputs the content for the current widget instance.
		 *
		 * @since 1.0.0
		 *
		 * @param array $args     Display arguments.
		 * @param array $instance Settings for the current widget instance.
		 */
		function widget( $args, $instance ) {

			$params = $this->get_params( $instance );

			echo $args['before_widget'];

			if ( ! empty( $params['title'] ) ) {
				echo $args['before_title'] . $params['title'] . $args['after_title'];
			}

			$qargs = array(
				'posts_per_page' => esc_attr( $params['post_number'] ),
				'no_found_rows'  => true,
				);
			if ( absint( $params['post_category'] ) > 0  ) {
				$qargs['category'] = $params['post_category'];
			}

			$all_posts = get_posts( $qargs );
			?>
			<?php if ( ! empty( $all_posts ) ) :  ?>

				<?php global $post; ?>

				<div class="advanced-recent-posts-widget">

					<?php foreach ( $all_posts as $key => $post ) :  ?>
						<?php setup_postdata( $post ); ?>

						<div class="advanced-recent-posts-item">

							<?php if ( 'disable' !== $params['featured_image'] && has_post_thumbnail() ) :  ?>
								<div class="advanced-recent-posts-thumb">
									<a href="<?php the_permalink(); ?>">
										<?php
										$img_attributes = array(
											'class' => 'alignleft',
											'style' => 'max-width:' . esc_attr( $params['image_width'] ). 'px;',
											);
										the_post_thumbnail( esc_attr( $params['featured_image'] ), $img_attributes );
										?>
									</a>
								</div><!-- .advanced-recent-posts-thumb -->
							<?php endif ?>
							<div class="advanced-recent-posts-text-wrap">
								<h3 class="advanced-recent-posts-title">
									<a href="<?php the_permalink(); ?>"><?php the_title(); ?></a>
								</h3><!-- .advanced-recent-posts-title -->

								<?php if ( false === $params['disable_date'] ) :  ?>
									<div class="advanced-recent-posts-meta">

										<?php if ( false === $params['disable_date'] ) :  ?>
											<span class="advanced-recent-posts-date"><?php the_time( get_option( 'date_format' ) ); ?></span><!-- .advanced-recent-posts-date -->
										<?php endif; ?>

									</div><!-- .advanced-recent-posts-meta -->
								<?php endif; ?>

								<?php if ( false === $params['disable_excerpt'] ) :  ?>
									<div class="advanced-recent-posts-summary">
										<?php
										$summary = wen_corporate_the_excerpt( esc_attr( $params['excerpt_length'] ), $post );
										echo wp_kses_post( wpautop( $summary ) );
										?>
									</div><!-- .advanced-recent-posts-summary -->
								<?php endif ?>
								<?php if ( false === $params['disable_more_text'] ) :  ?>
									<div class="advanced-recent-posts-read-more"><a href="<?php the_permalink(); ?>" class="read-more"><?php echo esc_html( $params['more_text'] ); ?></a></div><!-- .advanced-recent-posts-read-more -->
								<?php endif ?>
							</div><!-- .advanced-recent-posts-text-wrap -->

						</div><!-- .advanced-recent-posts-item .col-sm-3 -->

					<?php endforeach; ?>

				</div><!-- .advanced-recent-posts-widget -->

				<?php wp_reset_postdata(); // Reset. ?>

			<?php endif; ?>

			<?php echo $args['after_widget'];

		}
	}
endif;

if ( ! class_exists( 'WEN_Corporate_Latest_News_Widget' ) ) :
	/**
	 * Latest news widget Class.
	 *
	 * @since 1.0.0
	 */
	class WEN_Corporate_Latest_News_Widget extends WEN_Corporate_Widget_Base {

		/**
		 * Sets up a new widget instance.
		 *
		 * @since 1.0.0
		 */
		function __construct() {
			$opts = array(
				'classname'   => 'wen_corporate_widget_latest_news',
				'description' => __( 'Displays latest posts in grid.', 'wen-corporate' ),
				'customize_selective_refresh' => true,
				);
			$fields = array(
				'title' => array(
					'label' => __( 'Title:', 'wen-corporate' ),
					'type'  => 'text',
					'class' => 'widefat',
					),
				'post_category' => array(
					'label'           => __( 'Select Category:', 'wen-corporate' ),
					'type'            => 'dropdown-taxonomies',
					'show_option_all' => __( 'All Categories', 'wen-corporate' ),
					),
				'post_number' => array(
					'label'   => __( 'Number of Posts:', 'wen-corporate' ),
					'type'    => 'number',
					'default' => 4,
					'css'     => 'max-width:60px;',
					'min'     => 1,
					'max'     => 100,
					),
				'post_column' => array(
					'label'   => __( 'Number of Columns:', 'wen-corporate' ),
					'type'    => 'select',
					'default' => 4,
					'options' => wen_corporate_get_numbers_dropdown_options( 1, 4 ),
					),
				'featured_image' => array(
					'label'   => __( 'Featured Image:', 'wen-corporate' ),
					'type'    => 'select',
					'default' => 'medium',
					'options' => wen_corporate_get_image_sizes_options( true ),
					),
				'excerpt_length' => array(
					'label'       => __( 'Excerpt Length:', 'wen-corporate' ),
					'description' => __( 'in words', 'wen-corporate' ),
					'type'        => 'number',
					'css'         => 'max-width:60px;',
					'default'     => 15,
					'min'         => 1,
					'max'         => 400,
					'adjacent'    => true,
					),
				'more_text' => array(
					'label'   => __( 'More Text:', 'wen-corporate' ),
					'type'    => 'text',
					'default' => __( 'Read more', 'wen-corporate' ),
					),
				'disable_date' => array(
					'label'   => __( 'Disable Date', 'wen-corporate' ),
					'type'    => 'checkbox',
					'default' => false,
					),
				'disable_comment' => array(
					'label'   => __( 'Disable Comment', 'wen-corporate' ),
					'type'    => 'checkbox',
					'default' => false,
					),
				'disable_excerpt' => array(
					'label'   => __( 'Disable Excerpt', 'wen-corporate' ),
					'type'    => 'checkbox',
					'default' => false,
					),
				'disable_more_text' => array(
					'label'   => __( 'Disable More Text', 'wen-corporate' ),
					'type'    => 'checkbox',
					'default' => false,
					),
				);
			parent::__construct( 'wen-corporate-latest-news', __( 'Corporate: Latest News', 'wen-corporate' ), $opts, array(), $fields );
		}

		/**
		 * Outputs the content for the current widget instance.
		 *
		 * @since 1.0.0
		 *
		 * @param array $args     Display arguments.
		 * @param array $instance Settings for the current widget instance.
		 */
		function widget( $args, $instance ) {

			$params = $this->get_params( $instance );

			echo $args['before_widget'];

			if ( ! empty( $params['title'] ) ) {
				echo $args['before_title'] . $params['title'] . $args['after_title'];
			}

			$qargs = array(
				'posts_per_page' => esc_attr( $params['post_number'] ),
				'no_found_rows'  => true,
				);
			if ( absint( $params['post_category'] ) > 0  ) {
				$qargs['category'] = absint( $params['post_category'] );
			}
			$all_posts = get_posts( $qargs );
			?>
			<?php if ( ! empty( $all_posts ) ) :  ?>

				<?php global $post; ?>

				<div class="latest-news-widget latest-news-col-<?php echo esc_attr( $params['post_column'] ); ?>">

					<div class="inner-wrapper">

						<?php foreach ( $all_posts as $key => $post ) :  ?>
							<?php setup_postdata( $post ); ?>

							<div class="latest-news-item">
								<div class="latest-news-wrapper">
									<?php if ( 'disable' !== $params['featured_image'] && has_post_thumbnail() ) :  ?>
										<div class="latest-news-thumb">
											<a href="<?php the_permalink(); ?>">
												<?php
												$img_attributes = array( 'class' => 'aligncenter' );
												the_post_thumbnail( esc_attr( $params['featured_image'] ), $img_attributes );
												?>
											</a>
										</div><!-- .latest-news-thumb -->
									<?php endif ?>
									<div class="latest-news-text-wrap">
										<h3 class="latest-news-title">
											<a href="<?php the_permalink(); ?>" title="<?php the_title_attribute(); ?>"><?php the_title(); ?></a>
										</h3><!-- .latest-news-title -->

										<?php if ( false === $params['disable_date'] || ( false === $params['disable_comment'] && comments_open( get_the_ID() ) ) ) :  ?>
											<div class="latest-news-meta">

												<?php if ( false === $params['disable_date'] ) :  ?>
													<span class="latest-news-date"><?php the_time( get_option( 'date_format' ) ); ?></span><!-- .latest-news-date -->
												<?php endif; ?>

												<?php if ( false === $params['disable_comment'] ) :  ?>
													<?php
													if ( comments_open( get_the_ID() ) ) {
														echo '<span class="latest-news-comments">';
														comments_popup_link( '<span class="leave-reply">' . __( 'No Comment', 'wen-corporate' ) . '</span>', __( '1 Comment', 'wen-corporate' ), __( '% Comments', 'wen-corporate' ) );
														echo '</span>';
													}
													?>
												<?php endif; ?>

											</div><!-- .latest-news-meta -->
										<?php endif; ?>

										<?php if ( false === $params['disable_excerpt'] ) :  ?>
											<div class="latest-news-summary">
											<?php
											$summary = wen_corporate_the_excerpt( esc_attr( $params['excerpt_length'] ), $post );
											echo wp_kses_post( wpautop( $summary ) );
											?>
											</div><!-- .latest-news-summary -->
										<?php endif; ?>
										<?php if ( false === $params['disable_more_text'] ) :  ?>
											<div class="latest-news-read-more"><a href="<?php the_permalink(); ?>" class="read-more"><?php echo esc_html( $params['more_text'] ); ?></a></div><!-- .latest-news-read-more -->
										<?php endif; ?>
									</div><!-- .latest-news-text-wrap -->
								</div>
							</div>

						<?php endforeach; ?>

					</div><!-- .row -->

				</div><!-- .latest-news-widget -->

				<?php wp_reset_postdata(); // Reset. ?>

			<?php endif; ?>

			<?php echo $args['after_widget'];

		}
	}
endif;

if ( ! class_exists( 'WEN_Corporate_Teams_Widget' ) ) :
	/**
	 * Teams widget Class.
	 *
	 * @since 1.0.0
	 */
	class WEN_Corporate_Teams_Widget extends WEN_Corporate_Widget_Base {

		/**
		 * Sets up a new widget instance.
		 *
		 * @since 1.0.0
		 */
		function __construct() {
			$opts = array(
				'classname'   => 'wen_corporate_widget_teams',
				'description' => __( 'Displays posts as teams.', 'wen-corporate' ),
				'customize_selective_refresh' => true,
				);
			$fields = array(
				'title' => array(
					'label' => __( 'Title:', 'wen-corporate' ),
					'type'  => 'text',
					'class' => 'widefat',
					),
				'post_category' => array(
					'label'           => __( 'Select Category:', 'wen-corporate' ),
					'type'            => 'dropdown-taxonomies',
					'show_option_all' => __( 'All Categories', 'wen-corporate' ),
					),
				'post_number' => array(
					'label'   => __( 'Number of Posts:', 'wen-corporate' ),
					'type'    => 'number',
					'default' => 4,
					'css'     => 'max-width:60px;',
					'min'     => 1,
					'max'     => 100,
					),
				'post_column' => array(
					'label'   => __( 'Number of Columns:', 'wen-corporate' ),
					'type'    => 'select',
					'default' => 4,
					'options' => wen_corporate_get_numbers_dropdown_options( 3, 4 ),
					),
				'featured_image' => array(
					'label'   => __( 'Featured Image:', 'wen-corporate' ),
					'type'    => 'select',
					'default' => 'medium',
					'options' => wen_corporate_get_image_sizes_options( false ),
					),
				'excerpt_length' => array(
					'label'       => __( 'Excerpt Length:', 'wen-corporate' ),
					'description' => __( 'in words', 'wen-corporate' ),
					'type'        => 'number',
					'css'         => 'max-width:60px;',
					'default'     => 20,
					'min'         => 1,
					'max'         => 400,
					'adjacent'    => true,
					),
				'disable_excerpt' => array(
					'label'   => __( 'Disable Excerpt', 'wen-corporate' ),
					'type'    => 'checkbox',
					'default' => false,
					),
				);
			parent::__construct( 'wen-corporate-teams', __( 'Corporate: Teams', 'wen-corporate' ), $opts, array(), $fields );
		}

		/**
		 * Outputs the content for the current widget instance.
		 *
		 * @since 1.0.0
		 *
		 * @param array $args     Display arguments.
		 * @param array $instance Settings for the current widget instance.
		 */
		function widget( $args, $instance ) {

			$params = $this->get_params( $instance );

			echo $args['before_widget'];

			if ( ! empty( $params['title'] ) ) {
				echo $args['before_title'] . $params['title'] . $args['after_title'];
			}

			$qargs = array(
				'posts_per_page' => esc_attr( $params['post_number'] ),
				'no_found_rows'  => true,
				'meta_key'       => '_thumbnail_id',
				);
			if ( absint( $params['post_category'] ) > 0  ) {
				$qargs['category'] = absint( $params['post_category'] );
			}
			$all_posts = get_posts( $qargs );
			?>
			<?php if ( ! empty( $all_posts ) ) :  ?>

				<?php global $post; ?>

				<div class="our-team-widget our-team-col-<?php echo esc_attr( $params['post_column'] ); ?>">
					<div class="inner-wrapper">
						<?php foreach ( $all_posts as $key => $post ) :  ?>
							<?php setup_postdata( $post ); ?>
							<div class="our-team-item">
							<?php if ( has_post_thumbnail() ) :  ?>
								<div class="thumb-summary-wrap">
									<div class="our-team-thumb">
										<a href="<?php the_permalink(); ?>">
											<?php the_post_thumbnail( esc_attr( $params['featured_image'] ), array( 'class' => 'aligncenter' ) ); ?>
										</a>
									</div><!-- .our-team-thumb-->
									<div class="our-team-text-wrap">
										<h3 class="our-team-title"><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h3>
										<?php if ( true !== $params['disable_excerpt'] ) : ?>
											<div class="our-team-summary">
												<?php
												$summary = wen_corporate_the_excerpt( absint( $params['excerpt_length'] ), $post );
												echo wp_kses_post( wpautop( $summary ) );
												 ?>
											</div><!-- .our-team-summary -->
										<?php endif; ?>

									</div><!-- .our-team-text-wrap -->
								</div><!-- .thumb-summary-wrap-->

							<?php endif; ?>

							</div><!-- .our-team-item -->
						<?php endforeach; ?>

					</div><!-- .inner-wrapper -->
				</div><!-- .our-team-widget -->

				<?php wp_reset_postdata(); // Reset. ?>

			<?php endif; ?>

			<?php echo $args['after_widget'];

		}
	}
endif;

if ( ! class_exists( 'WEN_Corporate_Testimonials_Widget' ) ) :
	/**
	 * Testimonials widget Class.
	 *
	 * @since 1.0.0
	 */
	class WEN_Corporate_Testimonials_Widget extends WEN_Corporate_Widget_Base {

		/**
		 * Sets up a new widget instance.
		 *
		 * @since 1.0.0
		 */
		function __construct() {
			$opts = array(
				'classname'   => 'wen_corporate_widget_testimonials',
				'description' => __( 'Displays testominials posts as slider.', 'wen-corporate' ),
				);
			$fields = array(
				'title' => array(
					'label' => __( 'Title:', 'wen-corporate' ),
					'type'  => 'text',
					'class' => 'widefat',
					),
				'post_category' => array(
					'label'           => __( 'Select Category:', 'wen-corporate' ),
					'type'            => 'dropdown-taxonomies',
					'show_option_all' => __( 'All Categories', 'wen-corporate' ),
					),
				'post_number' => array(
					'label'   => __( 'Number of Posts:', 'wen-corporate' ),
					'type'    => 'number',
					'default' => 4,
					'css'     => 'max-width:60px;',
					'min'     => 1,
					'max'     => 100,
					),
				'featured_image' => array(
					'label'   => __( 'Featured Image:', 'wen-corporate' ),
					'type'    => 'select',
					'default' => 'thumbnail',
					'options' => wen_corporate_get_image_sizes_options( true, array( 'disable', 'thumbnail' ), false ),
					),
				'excerpt_length' => array(
					'label'       => __( 'Excerpt Length:', 'wen-corporate' ),
					'description' => __( 'in words', 'wen-corporate' ),
					'type'        => 'number',
					'css'         => 'max-width:60px;',
					'default'     => 40,
					'min'         => 1,
					'max'         => 400,
					'adjacent'    => true,
					),
				'transition_delay' => array(
					'label'       => __( 'Transition Delay:', 'wen-corporate' ),
					'description' => __( 'in seconds', 'wen-corporate' ),
					'type'        => 'number',
					'css'         => 'max-width:60px;',
					'default'     => 3,
					'min'         => 1,
					'max'         => 10,
					'adjacent'    => true,
					),
				'disable_autoplay' => array(
					'label'   => __( 'Disable Autoplay', 'wen-corporate' ),
					'type'    => 'checkbox',
					'default' => false,
					),
				'disable_pager' => array(
					'label'   => __( 'Disable Pager', 'wen-corporate' ),
					'type'    => 'checkbox',
					'default' => true,
					),
				'disable_prev_next_control' => array(
					'label'   => __( 'Disable Previous Next Control', 'wen-corporate' ),
					'type'    => 'checkbox',
					'default' => false,
					),
				);
			parent::__construct( 'wen-corporate-testimonials', __( 'Corporate: Testimonials', 'wen-corporate' ), $opts, array(), $fields );
		}

		/**
		 * Outputs the content for the current widget instance.
		 *
		 * @since 1.0.0
		 *
		 * @param array $args     Display arguments.
		 * @param array $instance Settings for the current widget instance.
		 */
		function widget( $args, $instance ) {

			$params = $this->get_params( $instance );

			echo $args['before_widget'];

			if ( ! empty( $params['title'] ) ) {
				echo $args['before_title'] . $params['title'] . $args['after_title'];
			}

			$qargs = array(
				'posts_per_page' => esc_attr( $params['post_number'] ),
				'no_found_rows'  => true,
				);
			if ( absint( $params['post_category'] ) > 0  ) {
				$qargs['category'] = $params['post_category'];
			}

			$all_posts = get_posts( $qargs );
			?>
			<?php if ( ! empty( $all_posts ) ) :  ?>

				<?php global $post; ?>
				<?php
					$carousel_args = array(
						'slidesToShow'  => 2,
						'autoplaySpeed' => absint( $params['transition_delay'] ) * 1000,
						'prevArrow'     => '<span data-role="none" class="slick-prev" tabindex="0"></span>',
						'nextArrow'     => '<span data-role="none" class="slick-next" tabindex="0"></span>',
						'responsive'    => array(
							array(
								'breakpoint' => 1024,
								'settings' => array(
									'slidesToShow' => 1,
									),
								),
							),
						);
					$carousel_args['autoplay'] = ( isset( $params['disable_autoplay'] ) && true === $params['disable_autoplay'] ) ? false : true ;
					$carousel_args['dots'] = ( isset( $params['disable_pager'] ) && true === $params['disable_pager'] ) ? false : true ;
					$carousel_args['arrows'] = ( isset( $params['disable_prev_next_control'] ) && true === $params['disable_prev_next_control'] ) ? false : true ;

					$carousel_args_encoded = wp_json_encode( $carousel_args );
				 ?>

				<div class="wen-corporate-carousel" data-slick='<?php echo $carousel_args_encoded; ?>'>
					<?php foreach ( $all_posts as $key => $post ) :  ?>
						<?php setup_postdata( $post ); ?>
						<div class="testimonial-item">
							<?php if ( has_post_thumbnail() && 'disable' !== $params['featured_image'] ) :  ?>
								<div class="testimonial-thumb">
									<?php the_post_thumbnail( esc_attr( $params['featured_image'] ) ); ?>
								</div><!-- .testimonial-thumb -->
							<?php endif ?>
							<div class="testimonial-summary">
								<?php
									$summary = wen_corporate_the_excerpt( esc_attr( $params['excerpt_length'] ), $post );
									echo wp_kses_post( wpautop( $summary ) );
								 ?>
							</div><!-- .testimonial-summary -->
							<h4><?php the_title(); ?></h4>
						</div>

					<?php endforeach; ?>

				</div><!-- .wen-corporate-carousel -->
				<?php wp_reset_postdata(); // Reset. ?>

			<?php endif; ?>

			<?php echo $args['after_widget'];

		}
	}
endif;
